@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2015-01-09'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-01-13'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,6 +65,9 @@ _
         exp_im_path => {
             schema => 'bool',
         },
+        dig_leaf => {
+            summary => 'bool',
+        },
         find_pm => {
             summary => 'Whether to find .pm files',
             schema  => 'bool*',
@@ -113,6 +116,7 @@ sub complete_module {
     my $ci          = $args{ci} // $Complete::OPT_CI;
     my $map_case    = $args{map_case} // $Complete::OPT_MAP_CASE;
     my $exp_im_path = $args{exp_im_path} // $Complete::OPT_EXP_IM_PATH;
+    my $dig_leaf    = $args{dig_leaf} // $Complete::OPT_DIG_LEAF;
     my $ns_prefix = $args{ns_prefix} // '';
     $ns_prefix =~ s/(::)+\z//;
 
@@ -149,7 +153,12 @@ sub complete_module {
     #$log->tracef('[compmod] invoking complete_path, word=<%s>', $word);
     my $res = Complete::Path::complete_path(
         word => $word,
-        ci => $ci, map_case => $map_case, exp_im_path => $exp_im_path,
+
+        ci => $ci,
+        map_case => $map_case,
+        exp_im_path => $exp_im_path,
+        dig_leaf=>$dig_leaf,
+
         starting_path => $ns_prefix,
         list_func => sub {
             my ($path, $intdir, $isint) = @_;
@@ -198,7 +207,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.14 of Complete::Module (from Perl distribution Complete-Module), released on 2015-01-09.
+This document describes version 0.15 of Complete::Module (from Perl distribution Complete-Module), released on 2015-01-13.
 
 =head1 SYNOPSIS
 
@@ -234,6 +243,10 @@ Arguments ('*' denotes required arguments):
 
 Whether to do case-insensitive search.
 
+=item * B<dig_leaf> => I<any>
+
+bool.
+
 =item * B<exp_im_path> => I<bool>
 
 =item * B<find_pm> => I<bool> (default: 1)
@@ -306,7 +319,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-M
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Module>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Module>.
 
 =head1 BUGS
 
